==> react-ui-5.0.0.tgz: package/Accordion.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var r = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, r) => {
            /******/ for (var t in r) {
                /******/ if (e.o(r, t) && !e.o(n, t)) {
                    /******/ Object.defineProperty(n, t, {
                        enumerable: true,
                        get: r[t]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        Panel: () => /* reexport */ O,
        default: () => /* reexport */ V
    });
    // CONCATENATED MODULE: external "react"
    const r = require("react");
    var t =  e.n(r);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var o =  e.n(a);
    // CONCATENATED MODULE: external "@splunk/react-ui/useControlled"
    const l = require("@splunk/react-ui/useControlled");
    var i =  e.n(l);
    // CONCATENATED MODULE: external "@splunk/react-ui/usePrevious"
    const u = require("@splunk/react-ui/usePrevious");
    var c =  e.n(u);
    // CONCATENATED MODULE: external "@splunk/react-ui/CollapsiblePanel"
    const s = require("@splunk/react-ui/CollapsiblePanel");
    var f =  e.n(s);
    // CONCATENATED MODULE: ./src/Accordion/AccordionContext.tsx
    var d =  (0, r.createContext)({});
    d.displayName = "Accordion";
    /* harmony default export */    const p = d;
    // CONCATENATED MODULE: ./src/Accordion/Panel.tsx
    function v() {
        return v = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, v.apply(null, arguments);
    }
    function y(e, n) {
        if (null == e) return {};
        var r, t, a = m(e, n);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (t = 0; t < o.length; t++) {
                r = o[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function m(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    var b = {
        description: o().string,
        elementRef: o().oneOfType([ o().func, o().object ]),
        inset: o().bool,
        panelId: o().any.isRequired,
        title: o().node.isRequired
    };
    var h = {
        flexShrink: 1
    };
    /**
 * `Accordion.Panel` operates as a container component for content in an `Accordion`.
 */    function g(e) {
        var n = e.panelId, a = e.inset, o = y(e, [ "panelId", "inset" ]);
        // @docs-props-type AccordionPanelPropsBase
                var l = (0, r.useContext)(d), i = l.onChange, u = l.openPanelId, c = l.inset;
        var s = u === n;
        var p = a !== undefined ? a : c;
        // Props are different based on controlled/uncontrolled
        // For controlled, onChange required prop for controlled cases and must be defined.
                var m = i ? {
            onChange: i,
            open: s
        } : {
            onChange: undefined
        };
        
        return t().createElement(f(), v({
            panelId: n,
            "data-test": "panel",
            inset: p,
            "data-test-panel-id": n,
            style: h
        }, o, m));
    }
    g.propTypes = b;
    /* harmony default export */    const O = g;
    // CONCATENATED MODULE: external "styled-components"
    const P = require("styled-components");
    var I =  e.n(P);
    // CONCATENATED MODULE: external "@splunk/react-ui/Box"
    const j = require("@splunk/react-ui/Box");
    var S =  e.n(j);
    // CONCATENATED MODULE: external "@splunk/themes"
    const C = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/Accordion/AccordionStyles.ts
    var w = I()(S()).withConfig({
        displayName: "AccordionStyles__StyledBox",
        componentId: "m39hyh-0"
    })([ "", ";flex-direction:column;margin-bottom:0;" ], C.mixins.reset("flex"));
    // CONCATENATED MODULE: ./src/Accordion/Accordion.tsx
    function q() {
        return q = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, q.apply(null, arguments);
    }
    function x(e, n) {
        return T(e) || R(e, n) || E(e, n) || A();
    }
    function A() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function E(e, n) {
        if (e) {
            if ("string" == typeof e) return k(e, n);
            var r = {}.toString.call(e).slice(8, -1);
            return "Object" === r && e.constructor && (r = e.constructor.name), "Map" === r || "Set" === r ? Array.from(e) : "Arguments" === r || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r) ? k(e, n) : void 0;
        }
    }
    function k(e, n) {
        (null == n || n > e.length) && (n = e.length);
        for (var r = 0, t = Array(n); r < n; r++) {
            t[r] = e[r];
        }
        return t;
    }
    function R(e, n) {
        var r = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != r) {
            var t, a, o, l, i = [], u = !0, c = !1;
            try {
                if (o = (r = r.call(e)).next, 0 === n) {
                    if (Object(r) !== r) return;
                    u = !1;
                } else for (;!(u = (t = o.call(r)).done) && (i.push(t.value), i.length !== n); u = !0) {
                }
            } catch (e) {
                c = !0, a = e;
            } finally {
                try {
                    if (!u && null != r["return"] && (l = r["return"](), Object(l) !== l)) return;
                } finally {
                    if (c) throw a;
                }
            }
            return i;
        }
    }
    function T(e) {
        if (Array.isArray(e)) return e;
    }
    function _(e, n) {
        if (null == e) return {};
        var r, t, a = M(e, n);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (t = 0; t < o.length; t++) {
                r = o[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function M(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    /** @public */    var N = {
        children: o().node,
        defaultOpenPanelId: o().any,
        elementRef: o().oneOfType([ o().func, o().object ]),
        inset: o().bool,
        onChange: o().func,
        openPanelId: o().any
    };
    /**
 * @deprecated
 * Accordion has been deprecated and will be removed in a future major version. Use Collapsible Panel's SingleOpenPanelGroup API instead.
 */    function B(e) {
        var n = e.children, a = e.defaultOpenPanelId, o = e.elementRef, l = e.inset, u = l === void 0 ? true : l, s = e.onChange, f = e.openPanelId, d = _(e, [ "children", "defaultOpenPanelId", "elementRef", "inset", "onChange", "openPanelId" ]);
        // @docs-props-type AccordionPropsBase
                (0, r.useEffect)((function() {
            if (false) {}
        }), []);
        var v = c()(a);
        (0, r.useEffect)((function() {
            if (false) {}
        }), [ a, v ]);
        var y = i()({
            componentName: "Accordion",
            /* eslint-disable-next-line prefer-rest-params */
            componentProps: arguments[0],
            // see SUI-7028
            defaultValuePropName: "defaultOpenPanelId",
            valuePropName: "openPanelId"
        });
        var m = (0, r.useState)(a), b = x(m, 2), h = b[0], g = b[1];
        var O = y ? f : h;
        var P = r.Children.toArray(n).filter(r.isValidElement);
 // remove false, null, 0, etc
                var I = (0, r.useCallback)((function(e, n) {
            var r = n.panelId, t = n.reason;
            // if the open panel is clicked on, collapse it
                        var a = O === r ? undefined : r;
            if (!y) {
                g(a);
            }
            s === null || s === void 0 ? void 0 : s(e, {
                event: e,
                panelId: a,
                reason: t
            });
        }), [ y, s, O ]);
        var j = (0, r.useMemo)((function() {
            return {
                inset: u,
                onChange: I,
                openPanelId: O
            };
        }), [ I, u, O ]);
        
        return t().createElement(w, q({
            "data-test": "accordion",
            "data-test-open-panel-id": O,
            elementRef: o
        }, d),  t().createElement(p.Provider, {
            value: j
        }, P));
    }
    B.propTypes = N;
    B.Panel = O;
    /* harmony default export */    const V = B;
    // CONCATENATED MODULE: ./src/Accordion/index.ts
    module.exports = n;
    /******/})();

==> react-ui-5.1.0.tgz: package/Accordion.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = n => {
            /******/ var r = n && n.__esModule ? 
            /******/ () => n["default"]
            /******/ : () => n
            /******/;
            e.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (n, r) => {
            /******/ for (var t in r) {
                /******/ if (e.o(r, t) && !e.o(n, t)) {
                    /******/ Object.defineProperty(n, t, {
                        enumerable: true,
                        get: r[t]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, n) => Object.prototype.hasOwnProperty.call(e, n)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var n = {};
    // ESM COMPAT FLAG
        e.r(n);
    // EXPORTS
        e.d(n, {
        Panel: () => /* reexport */ w,
        default: () => /* reexport */ V
    });
    // CONCATENATED MODULE: external "react"
    const r = require("react");
    var t =  e.n(r);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var o =  e.n(a);
    // CONCATENATED MODULE: external "@splunk/react-ui/useControlled"
    const l = require("@splunk/react-ui/useControlled");
    var i =  e.n(l);
    // CONCATENATED MODULE: external "@splunk/react-ui/usePrevious"
    const u = require("@splunk/react-ui/usePrevious");
    var c =  e.n(u);
    // CONCATENATED MODULE: external "styled-components"
    const s = require("styled-components");
    var f =  e.n(s);
    // CONCATENATED MODULE: external "@splunk/react-ui/Box"
    const d = require("@splunk/react-ui/Box");
    var p =  e.n(d);
    // CONCATENATED MODULE: external "@splunk/themes"
    const v = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/Accordion/AccordionStyles.ts
    var y = f()(p()).withConfig({
        displayName: "AccordionStyles__StyledBox",
        componentId: "m39hyh-0"
    })([ "", ";flex-direction:column;margin-bottom:0;" ], v.mixins.reset("flex"));
    // CONCATENATED MODULE: external "@splunk/react-ui/CollapsiblePanel"
    const m = require("@splunk/react-ui/CollapsiblePanel");
    var b =  e.n(m);
    // CONCATENATED MODULE: ./src/Accordion/AccordionContext.tsx
    var h =  (0, r.createContext)({});
    h.displayName = "Accordion";
    /* harmony default export */    const g = h;
    // CONCATENATED MODULE: ./src/Accordion/Panel.tsx
    function O() {
        return O = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, O.apply(null, arguments);
    }
    function P(e, n) {
        if (null == e) return {};
        var r, t, a = I(e, n);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (t = 0; t < o.length; t++) {
                r = o[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function I(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    var j = {
        description: o().string,
        elementRef: o().oneOfType([ o().func, o().object ]),
        inset: o().bool,
        panelId: o().any.isRequired,
        title: o().node.isRequired
    };
    var S = {
        flexShrink: 1
    };
    /**
 * `Accordion.Panel` operates as a container component for content in an `Accordion`.
 */    function C(e) {
        var n = e.panelId, a = e.inset, o = P(e, [ "panelId", "inset" ]);
        // @docs-props-type AccordionPanelPropsBase
                var l = (0, r.useContext)(h), i = l.onChange, u = l.openPanelId, c = l.inset;
        var s = u === n;
        var f = a !== undefined ? a : c;
        // Props are different based on controlled/uncontrolled
        // For controlled, onChange required prop for controlled cases and must be defined.
                var d = i ? {
            onChange: i,
            open: s
        } : {
            onChange: undefined
        };
        
        return t().createElement(b(), O({
            panelId: n,
            "data-test": "panel",
            inset: f,
            "data-test-panel-id": n,
            style: S
        }, o, d));
    }
    C.propTypes = j;
    /* harmony default export */    const w = C;
    // CONCATENATED MODULE: ./src/Accordion/Accordion.tsx
    function q() {
        return q = Object.assign ? Object.assign.bind() : function(e) {
            for (var n = 1; n < arguments.length; n++) {
                var r = arguments[n];
                for (var t in r) {
                    ({}).hasOwnProperty.call(r, t) && (e[t] = r[t]);
                }
            }
            return e;
        }, q.apply(null, arguments);
    }
    function x(e, n) {
        return T(e) || R(e, n) || E(e, n) || A();
    }
    function A() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function E(e, n) {
        if (e) {
            if ("string" == typeof e) return k(e, n);
            var r = {}.toString.call(e).slice(8, -1);
            return "Object" === r && e.constructor && (r = e.constructor.name), "Map" === r || "Set" === r ? Array.from(e) : "Arguments" === r || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r) ? k(e, n) : void 0;
        }
    }
    function k(e, n) {
        (null == n || n > e.length) && (n = e.length);
        for (var r = 0, t = Array(n); r < n; r++) {
            t[r] = e[r];
        }
        return t;
    }
    function R(e, n) {
        var r = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != r) {
            var t, a, o, l, i = [], u = !0, c = !1;
            try {
                if (o = (r = r.call(e)).next, 0 === n) {
                    if (Object(r) !== r) return;
                    u = !1;
                } else for (;!(u = (t = o.call(r)).done) && (i.push(t.value), i.length !== n); u = !0) {
                }
            } catch (e) {
                c = !0, a = e;
            } finally {
                try {
                    if (!u && null != r["return"] && (l = r["return"](), Object(l) !== l)) return;
                } finally {
                    if (c) throw a;
                }
            }
            return i;
        }
    }
    function T(e) {
        if (Array.isArray(e)) return e;
    }
    function _(e, n) {
        if (null == e) return {};
        var r, t, a = M(e, n);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (t = 0; t < o.length; t++) {
                r = o[t], n.includes(r) || {}.propertyIsEnumerable.call(e, r) && (a[r] = e[r]);
            }
        }
        return a;
    }
    function M(e, n) {
        if (null == e) return {};
        var r = {};
        for (var t in e) {
            if ({}.hasOwnProperty.call(e, t)) {
                if (n.includes(t)) continue;
                r[t] = e[t];
            }
        }
        return r;
    }
    /** @public */    var N = {
        children: o().node,
        defaultOpenPanelId: o().any,
        elementRef: o().oneOfType([ o().func, o().object ]),
        inset: o().bool,
        onChange: o().func,
        openPanelId: o().any
    };
    /**
 * @deprecated
 * Accordion has been deprecated and will be removed in a future major version. Use Collapsible Panel's SingleOpenPanelGroup API instead.
 */    function B(e) {
        var n = e.children, a = e.defaultOpenPanelId, o = e.elementRef, l = e.inset, u = l === void 0 ? true : l, s = e.onChange, f = e.openPanelId, d = _(e, [ "children", "defaultOpenPanelId", "elementRef", "inset", "onChange", "openPanelId" ]);
        // @docs-props-type AccordionPropsBase
                (0, r.useEffect)((function() {
            if (false) {}
        }), []);
        var p = c()(a);
        (0, r.useEffect)((function() {
            if (false) {}
        }), [ a, p ]);
        var v = i()({
            componentName: "Accordion",
            /* eslint-disable-next-line prefer-rest-params */
            componentProps: arguments[0],
            // see SUI-7028
            defaultValuePropName: "defaultOpenPanelId",
            valuePropName: "openPanelId"
        });
        var m = (0, r.useState)(a), b = x(m, 2), h = b[0], O = b[1];
        var P = v ? f : h;
        var I = r.Children.toArray(n).filter(r.isValidElement);
 // remove false, null, 0, etc
                var j = (0, r.useCallback)((function(e, n) {
            var r = n.panelId, t = n.reason;
            // if the open panel is clicked on, collapse it
                        var a = P === r ? undefined : r;
            if (!v) {
                O(a);
            }
            s === null || s === void 0 ? void 0 : s(e, {
                event: e,
                panelId: a,
                reason: t
            });
        }), [ v, s, P ]);
        var S = (0, r.useMemo)((function() {
            return {
                inset: u,
                onChange: j,
                openPanelId: P
            };
        }), [ j, u, P ]);
        
        return t().createElement(y, q({
            "data-test": "accordion",
            "data-test-open-panel-id": P,
            elementRef: o
        }, d),  t().createElement(g.Provider, {
            value: S
        }, I));
    }
    B.propTypes = N;
    B.Panel = w;
    /* harmony default export */    const V = B;
    // CONCATENATED MODULE: ./src/Accordion/index.ts
    module.exports = n;
    /******/})();
